/*
 * ====================================================================
 *
 * MIT License
 * 
 * Copyright (c) [2022] 
 * [Jan Grossniklaus, Jan Kunert, Sascha Hildebrands, Kevin Hinrichs]
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use, copy, 
 * modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is
 * urnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall
 * be included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * 
 * ====================================================================
 */

#ifndef PROJECT_H_
#define PROJECT_H_

//https://www.mikrocontroller.net/articles/FAQ#Globale_Variablen_%C3%BCber_mehrere_Dateien
#ifndef EXTERN
#define EXTERN extern
#endif

#include <arm_math.h> // float datatype

//*********************************************************************
//
// Precompiler adjustments for some extra or test stuff
//
//*********************************************************************

// debug off
//#define DEBUG_OFF

//*********************************************************************
//
// This is the global header file for thies project
//
//*********************************************************************

//*********************************************************************
//
// Defines to setup the LED-Driver. No changes here!
//
//*********************************************************************
#define SIGNAL_FREQUENZ 800000 // 800kHz from Datasheet
#define SIGNAL_RESET_FREQUENZ 3600 //3.6kHz (>280micros) from Datasheet
#define SIGNAL_DMA 29 // // // DMA Request after a 1 Signal
#define SIGNAL_RESET 98 // DC 1% (0% does not work)

//*********************************************************************
//
// Defines for Debug
//
//*********************************************************************
#define DEBUG_PA2 ((volatile uint32_t *)GPIO_PORTA_BASE)[GPIO_PIN_2]
#define DEBUG_PA3 ((volatile uint32_t *)GPIO_PORTA_BASE)[GPIO_PIN_3]
#define DEBUG_PA4 ((volatile uint32_t *)GPIO_PORTA_BASE)[GPIO_PIN_4]
#define DEBUG_PA5 ((volatile uint32_t *)GPIO_PORTA_BASE)[GPIO_PIN_5]
#define DEBUG_PA6 ((volatile uint32_t *)GPIO_PORTA_BASE)[GPIO_PIN_6]

#define DEBUG_PC4 ((volatile uint32_t *)GPIO_PORTC_BASE)[GPIO_PIN_4]
#define DEBUG_PC5 ((volatile uint32_t *)GPIO_PORTC_BASE)[GPIO_PIN_5]
#define DEBUG_PC6 ((volatile uint32_t *)GPIO_PORTC_BASE)[GPIO_PIN_6]

#define DEBUG_PD6 ((volatile uint32_t *)GPIO_PORTD_BASE)[GPIO_PIN_6]
#define DEBUG_PD7 ((volatile uint32_t *)GPIO_PORTD_BASE)[GPIO_PIN_7]

#define DEBUG_PE0 ((volatile uint32_t *)GPIO_PORTE_BASE)[GPIO_PIN_0]
#define DEBUG_PE1 ((volatile uint32_t *)GPIO_PORTE_BASE)[GPIO_PIN_1]
#define DEBUG_PE2 ((volatile uint32_t *)GPIO_PORTE_BASE)[GPIO_PIN_2]
#define DEBUG_PE3 ((volatile uint32_t *)GPIO_PORTE_BASE)[GPIO_PIN_3]
#define DEBUG_PE4 ((volatile uint32_t *)GPIO_PORTE_BASE)[GPIO_PIN_4]
#define DEBUG_PE5 ((volatile uint32_t *)GPIO_PORTE_BASE)[GPIO_PIN_5]

#define DEBUG_PF0 ((volatile uint32_t *)GPIO_PORTF_BASE)[GPIO_PIN_0]
#define DEBUG_PF1 ((volatile uint32_t *)GPIO_PORTF_BASE)[GPIO_PIN_1]
#define DEBUG_PF3 ((volatile uint32_t *)GPIO_PORTF_BASE)[GPIO_PIN_3]
#define DEBUG_PF4 ((volatile uint32_t *)GPIO_PORTF_BASE)[GPIO_PIN_4]

//*********************************************************************
//
// Data Structures for uDMA
//
//*********************************************************************

enum UDMA_TRANSFER_STATE
{
    EMPTY,
    FILLING,
    FULL
};

//*********************************************************************
//
// Globale Variablen for uDMA Management
//
//*********************************************************************
#pragma data_alignment=1024
EXTERN uint8_t uDMAControlTable[1024]; // 1.024 Bytes SRAM

#ifndef DEBUG_OFF
EXTERN volatile uint32_t uDMAErrorHandlerCounter;
#endif

#endif //PROJECT_H_